@@ -104,9 +104,9 @@ fn ensure_array_multiline(array: &SyntaxNode, column_width: usize) {
         return;
     }
 
-    let has_comment = array.descendants_with_tokens().any(|x| x.kind() == COMMENT);
+    let has_comment_inside = has_comment_before_bracket_end(array);
     let exceeds_width = array.text().to_string().len() > column_width;
-    if !has_trailing && !exceeds_width && !has_comment {
+    if !has_trailing && !exceeds_width && !has_comment_inside {
         return;
     }
 
@@ -117,6 +117,25 @@ fn ensure_array_multiline(array: &SyntaxNode, column_width: usize) {
     insert_newlines_around_content(array);
 }
 
+fn has_comment_before_bracket_end(array: &SyntaxNode) -> bool {
+    let children: Vec<_> = array.children_with_tokens().collect();
+    let mut seen_bracket_end = false;
+    for child in children.iter().rev() {
+        if child.kind() == BRACKET_END {
+            seen_bracket_end = true;
+        } else if seen_bracket_end && child.kind() == COMMENT {
+            return true;
+        } else if seen_bracket_end
+            && is_array_value(child.kind())
+            && let Some(node) = child.as_node()
+            && node.descendants_with_tokens().any(|x| x.kind() == COMMENT)
+        {
+            return true;
+        }
+    }
+    false
+}
+
 pub fn transform<F>(array: &SyntaxNode, transform: &F)
 where
     F: Fn(&str) -> String,
@@ -271,16 +290,14 @@ where
 {
     sort(
         node,
-        |e| -> Option<String> {
+        |e| {
             let kind = e.kind();
-            if kind == BASIC_STRING || kind == LITERAL_STRING {
+            (kind == BASIC_STRING || kind == LITERAL_STRING).then(|| {
                 e.descendants_with_tokens()
                     .filter_map(|elem| elem.into_token())
                     .find(|token| token.kind() == kind)
                     .map(|token| to_key(load_text(token.text(), kind)))
-            } else {
-                None
-            }
+            })?
         },
         cmp,
     );
@@ -385,10 +402,6 @@ fn align_comments_in_array(array: &SyntaxNode) {
                         j += 1;
                     }
                     WHITESPACE => j += 1,
-                    COMMENT => {
-                        comma_idx = Some(j);
-                        break;
-                    }
                     _ => break,
                 }
             }
